@@ -25,7 +25,7 @@ class TestCLIInterface(InterfaceUnitTests):
         Returns:
             ConsoleInterface -- The Interface object to use for the CPPython defined tests
         """
-        return ConsoleInterface(default_pyproject)
+        return ConsoleInterface()
 
     # Grab the API methods and parameterize them for automatic testing of the entry_points
     method_list = [func for func in dir(API) if callable(getattr(API, func)) and not func.startswith("__")]
